@@ -1,7 +1,33 @@
 # The supported rho families.
 
 #FAMILY.NAMES <- c("bisquare", "ggw", "hampel", "huber", "lqq", "mopt", "opt", "welsh")
-FAMILY.NAMES <- c("bisquare", "mopt", "opt")
+FAMILY.NAMES <- c("bisquare", "mopt", "opt", "huber")
+
+#' Tuning parameter the rho loss functions
+#'
+#' This function computes the tuning constant that yields an MM-regression
+#' estimator with a desired asymptotic efficiency when computed with a
+#' rho function in the corresponding family. The output of this
+#' function can be passed to the functions \link{lmrobdet.control},
+#' \link{mscale} and \link{rho}.
+#'
+#' @param e the desired efficiency of the corresponding regression
+#' estimator for Gaussian errors
+#'
+#' @return A length-1 vector with the corresponding tuning constant.
+#'
+#' @rdname huber
+#' @author Kjell Konis
+#'
+#' @examples
+#' # Tuning parameters for an 85%-efficient M-estimator at a Gaussian model
+#' huber(.95)
+#'
+#' @export
+huber <- function(e) #, breakdown.point)
+{
+  findTuningConstFromGaussianEfficiency(e, "huber")
+}
 
 
 #' Tuning parameter the rho loss functions
